@@ -1,5 +1,5 @@
 from django.conf import settings
-from django.contrib.sites.models import get_current_site
+from django.contrib.sites.shortcuts import get_current_site
 from wafer.menu import get_cached_menus
 
 
@@ -8,6 +8,19 @@ def site_info(request):
     site = get_current_site(request)
     context = {
         'WAFER_CONFERENCE_NAME': site.name,
+        'WAFER_CONFERENCE_DOMAIN': site.domain,
+    }
+    return context
+
+
+def navigation_info(request):
+    '''Expose whether to display the navigation header and footer'''
+    if request.GET.get('wafer_hide_navigation') == "1":
+        nav_class = "wafer-invisible"
+    else:
+        nav_class = "wafer-visible"
+    context = {
+        'WAFER_NAVIGATION_VISIBILITY': nav_class,
     }
     return context
 
@@ -24,6 +37,11 @@ def menu_info(request):
 def registration_settings(request):
     '''Expose selected settings to templates'''
     context = {}
-    for setting in ('WAFER_GITHUB_CLIENT_ID', 'WAFER_HIDE_LOGIN'):
+    for setting in (
+            'WAFER_SSO',
+            'WAFER_HIDE_LOGIN',
+            'WAFER_REGISTRATION_OPEN',
+            'WAFER_REGISTRATION_MODE',
+    ):
         context[setting] = getattr(settings, setting, None)
     return context
