@@ -7,9 +7,6 @@ from django.contrib.auth.models import Group, Permission
 class Command(BaseCommand):
     help = "Add some useful default groups"
 
-    option_list = BaseCommand.option_list + tuple([
-    ])
-
     GROUPS = {
         # Permissions are specified as (app, code_name) pairs
         'Page Editors': (
@@ -19,7 +16,9 @@ class Command(BaseCommand):
         ),
         'Talk Mentors': (
             ('talks', 'change_talk'), ('talks', 'view_all_talks'),
+            ('talks', 'edit_private_notes'),
         ),
+        'Registration': (),
     }
 
     def add_wafer_groups(self):
@@ -39,6 +38,7 @@ class Command(BaseCommand):
                     continue
                 except Permission.MultipleObjectsReturned:
                     print('Non-unique permission %s' % perm_code)
+                    continue
                 if perm not in group.permissions.all():
                     print('Adding %s to %s' % (perm_code, wafer_group))
                     group.permissions.add(perm)
