@@ -19,10 +19,19 @@ class WaferDiskStaticSiteRenderer(DiskStaticSiteRenderer):
                                                                      view)
             except IOError as err:
                 print('Skiping %s - threw IOError %s' % (path, err))
-            # This is a hack because dajngo_medusa doens't understand 301
-            if path == '/':
-                DEPLOY_DIR = settings.MEDUSA_DEPLOY_DIR
-                # Also copy to index, as specified by the pages url
-                outpath = os.path.join(DEPLOY_DIR, 'index')
-                inpath = os.path.join(DEPLOY_DIR, 'index.html')
-                shutil.copyfile(inpath, outpath)
+
+    # Copy static assets into place.
+    @classmethod
+    def finalize_output(self):
+        DiskStaticSiteRenderer.finalize_output()
+
+        static_path = os.path.join(settings.MEDUSA_DEPLOY_DIR,
+                                   settings.STATIC_URL.lstrip('/'))
+        media_path = os.path.join(settings.MEDUSA_DEPLOY_DIR,
+                                  settings.MEDIA_URL.lstrip('/'))
+
+        shutil.rmtree(static_path, ignore_errors=True)
+        shutil.rmtree(media_path, ignore_errors=True)
+
+        shutil.copytree(settings.STATIC_ROOT, static_path)
+        shutil.copytree(settings.MEDIA_ROOT, media_path)
