@@ -2,17 +2,18 @@ import os
 
 from django.utils.translation import ugettext_lazy as _
 
+try:
+    from localsettings import *
+except ImportError:
+    pass
+
 # Django settings for wafer project.
 
-DEBUG = True
-TEMPLATE_DEBUG = DEBUG
-
 ADMINS = (
+    # The logging config below mails admins
     # ('Your Name', 'your_email@example.com'),
 )
 
-MANAGERS = ADMINS
-
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
@@ -20,6 +21,13 @@ DATABASES = {
     }
 }
 
+if os.environ.get('TESTDB', None) == 'postgres':
+    DATABASES['default'].update({
+        'ENGINE': 'django.db.backends.postgresql_psycopg2',
+        'USER': 'postgres',
+        'NAME': 'wafer',
+        })
+
 # Hosts/domain names that are valid for this site; required if DEBUG is False
 # See https://docs.djangoproject.com/en/1.5/ref/settings/#allowed-hosts
 ALLOWED_HOSTS = []
@@ -28,7 +36,7 @@ ALLOWED_HOSTS = []
 # http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
 # although not all choices may be available on all operating systems.
 # In a Windows environment this must be set to your system time zone.
-TIME_ZONE = 'Africa/Johannesburg'
+TIME_ZONE = 'UTC'
 
 # Language code for this installation. All choices can be found here:
 # http://www.i18nguy.com/unicode/language-identifiers.html
@@ -61,7 +69,7 @@ MEDIA_URL = '/media/'
 # Don't put anything in this directory yourself; store your static files
 # in apps' "static/" subdirectories and in STATICFILES_DIRS.
 # Example: "/var/www/example.com/static/"
-STATIC_ROOT = ''
+STATIC_ROOT = os.path.join(project_root, 'static')
 
 # URL prefix for static files.
 # Example: "http://example.com/static/", "http://static.example.com/"
@@ -72,7 +80,6 @@ STATICFILES_DIRS = (
     # Put strings here, like "/home/html/static" or "C:/www/django/static".
     # Always use forward slashes, even on Windows.
     # Don't forget to use absolute paths, not relative paths.
-    os.path.join(project_root, 'bower_components'),
 )
 
 # List of finder classes that know how to find static files in
@@ -86,12 +93,33 @@ STATICFILES_FINDERS = (
 # Make this unique, and don't share it with anybody.
 SECRET_KEY = '8iysa30^no&oi5kv$k1w)#gsxzrylr-h6%)loz71expnbf7z%)'
 
-# List of callables that know how to import templates from various sources.
-TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.Loader',
-    'django.template.loaders.app_directories.Loader',
-    # 'django.template.loaders.eggs.Loader',
-)
+TEMPLATES = [
+    {
+        'APP_DIRS': True,
+        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        'DIRS': (
+            # Put strings here, like "/home/html/django_templates" or
+            # "C:/www/django/templates". Always use forward slashes, even on Windows.
+            # Don't forget to use absolute paths, not relative paths.
+        ),
+        'OPTIONS': {
+            'context_processors': (
+                'django.contrib.auth.context_processors.auth',
+                'django.template.context_processors.debug',
+                'django.template.context_processors.i18n',
+                'django.template.context_processors.media',
+                'django.template.context_processors.static',
+                'django.template.context_processors.tz',
+                'django.contrib.messages.context_processors.messages',
+                'wafer.context_processors.site_info',
+                'wafer.context_processors.navigation_info',
+                'wafer.context_processors.menu_info',
+                'wafer.context_processors.registration_settings'
+            )
+        }
+    },
+]
+
 
 MIDDLEWARE_CLASSES = (
     'django.middleware.common.CommonMiddleware',
@@ -99,6 +127,7 @@ MIDDLEWARE_CLASSES = (
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
+    'django.contrib.redirects.middleware.RedirectFallbackMiddleware',
     # Uncomment the next line for simple clickjacking protection:
     # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
 )
@@ -108,24 +137,6 @@ ROOT_URLCONF = 'wafer.urls'
 # Python dotted path to the WSGI application used by Django's runserver.
 WSGI_APPLICATION = 'wafer.wsgi.application'
 
-TEMPLATE_DIRS = (
-    # Put strings here, like "/home/html/django_templates" or
-    # "C:/www/django/templates". Always use forward slashes, even on Windows.
-    # Don't forget to use absolute paths, not relative paths.
-)
-
-TEMPLATE_CONTEXT_PROCESSORS = (
-    'django.contrib.auth.context_processors.auth',
-    'django.core.context_processors.debug',
-    'django.core.context_processors.i18n',
-    'django.core.context_processors.media',
-    'django.core.context_processors.static',
-    'django.core.context_processors.tz',
-    'django.contrib.messages.context_processors.messages',
-    'wafer.context_processors.site_info',
-    'wafer.context_processors.menu_info',
-    'wafer.context_processors.registration_settings',
-)
 
 INSTALLED_APPS = (
     'django.contrib.auth',
@@ -134,13 +145,16 @@ INSTALLED_APPS = (
     'django.contrib.sites',
     'django.contrib.messages',
     'django.contrib.staticfiles',
-    'django.contrib.admin',
+    'django.contrib.redirects',
+    'reversion',
     'django_medusa',
     'crispy_forms',
     'django_nose',
-    'registration',
     'markitup',
+    'rest_framework',
+    'easy_select2',
     'wafer',
+    'wafer.kv',
     'wafer.registration',
     'wafer.talks',
     'wafer.schedule',
@@ -148,18 +162,12 @@ INSTALLED_APPS = (
     'wafer.sponsors',
     'wafer.pages',
     'wafer.tickets',
+    'wafer.compare',
+    # Django isn't finding the overridden templates
+    'registration',
+    'django.contrib.admin',
 )
 
-# Only add south if we're on a version that doesn't support native migrations
-# (native migrations were added in Django 1.7)
-try:
-    from django.db import migrations
-    WAFER_NEEDS_SOUTH = False
-except ImportError:
-    INSTALLED_APPS += ('south', )
-    WAFER_NEEDS_SOUTH = True
-
-
 TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
 
 # A sample logging configuration. The only tangible logging
@@ -193,18 +201,11 @@ LOGGING = {
 
 # Django registration:
 ACCOUNT_ACTIVATION_DAYS = 7
-AUTH_PROFILE_MODULE = 'users.UserProfile'
 
 AUTH_USER_MODEL = 'auth.User'
 
 # Forms:
-CRISPY_FAIL_SILENTLY = not DEBUG
-
-import django.template
-django.template.add_to_builtins('django.templatetags.future')
-django.template.add_to_builtins('django.templatetags.i18n')
-
-CRISPY_TEMPLATE_PACK = 'bootstrap3'
+CRISPY_TEMPLATE_PACK = 'bootstrap4'
 
 # Wafer cache settings
 # We assume that the WAFER_CACHE is cross-process
@@ -242,14 +243,27 @@ WAFER_DYNAMIC_MENUS = (
     'wafer.pages.models.page_menus',
 )
 
+# Enabled SSO mechanims:
+WAFER_SSO = (
+    # 'github',
+    # 'debian',
+)
+
 # Log in with GitHub:
-# AUTHENTICATION_BACKENDS = (
-#     'django.contrib.auth.backends.ModelBackend',
-#     'wafer.registration.backends.GitHubBackend',
-# )
 # WAFER_GITHUB_CLIENT_ID = 'register on github'
 # WAFER_GITHUB_CLIENT_SECRET = 'to get these secrets'
 
+# Log in with Debian SSO:
+# Requires some Apache config:
+# SSLCACertificateFile /srv/sso.debian.org/etc/debsso.crt
+# SSLCARevocationCheck chain
+# SSLCARevocationFile /srv/sso.debian.org/etc/debsso.crl
+# <Location /accounts/debian-login/>
+#     SSLOptions +StdEnvVars
+#     SSLVerifyClient optional
+# </Location>
+# WAFER_DEBIAN_NM_API_KEY = 'obtain one from https://nm.debian.org/apikeys/'
+
 # Set this to true to disable the login button on the navigation toolbar
 WAFER_HIDE_LOGIN = False
 
@@ -257,6 +271,24 @@ WAFER_HIDE_LOGIN = False
 # Set this to False to disable talk submissions
 WAFER_TALKS_OPEN = True
 
+# The form used for talk submission
+WAFER_TALK_FORM = 'wafer.talks.forms.TalkForm'
+
+# Ask speakers for video release, and an email address of a reviewer
+WAFER_VIDEO = True
+WAFER_VIDEO_REVIEWER = True
+
+# Set this to False to disable registration
+WAFER_REGISTRATION_OPEN = True
+# Can be 'ticket' for Quicket tickets or 'form' for a classic form
+WAFER_REGISTRATION_MODE = 'ticket'
+
+# For REGISTRATION_MODE == 'form', the form to present
+WAFER_REGISTRATION_FORM = 'wafer.users.forms.ExampleRegistrationForm'
+
+# Allow registered and anonymous users to see registered users
+WAFER_PUBLIC_ATTENDEE_LIST = True
+
 # Ticket registration with Quicket
 # WAFER_TICKET_SECRET = "i'm a shared secret"
 
@@ -264,3 +296,8 @@ WAFER_TALKS_OPEN = True
 MEDUSA_RENDERER_CLASS = "wafer.management.static.WaferDiskStaticSiteRenderer"
 MEDUSA_DEPLOY_DIR = os.path.join(project_root, 'static_mirror')
 MARKITUP_FILTER = ('markdown.markdown', {'safe_mode': True})
+
+REST_FRAMEWORK = {
+    'DEFAULT_PERMISSION_CLASSES': ('rest_framework.permissions.IsAdminUser',),
+    'PAGE_SIZE': 50
+}
