@@ -1,7 +1,6 @@
 # From http://djangosnippets.org/snippets/882/
 # Copyright carljm (http://djangosnippets.org/users/carljm/)
 
-from django.conf import settings
 from django.db.models import TextField
 from markdown import markdown
 
@@ -59,14 +58,3 @@ class MarkdownTextField(TextField):
 
     def __str__(self):
         return self.attname
-
-
-if settings.WAFER_NEEDS_SOUTH:
-    from south.modelsinspector import add_introspection_rules
-
-    add_introspection_rules([(
-        [MarkdownTextField], [], {
-            "allow_html": ["_markdown_safe", {"default": True}],
-            "html_field_suffix": ["_html_field_suffix", {"default": "_html"}],
-        },
-    )], ["^wafer\.snippets\.markdown_field\.MarkdownTextField"])
