@@ -5,7 +5,10 @@ from django.utils.encoding import python_2_unicode_compatible
 
 @python_2_unicode_compatible
 class TicketType(models.Model):
-    name = models.CharField(max_length=32)
+
+    MAX_NAME_LENGTH = 255
+
+    name = models.CharField(max_length=MAX_NAME_LENGTH)
 
     def __str__(self):
         return self.name
