@@ -1,13 +1,18 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import include, url
+from rest_framework import routers
 
 from wafer.users.views import (UsersView, ProfileView, EditProfileView,
-                               EditUserView)
+                               EditUserView, RegistrationView, UserViewSet)
 
-urlpatterns = patterns(
-    '',
+
+router = routers.DefaultRouter()
+router.register(r'users', UserViewSet)
+
+urlpatterns = [
     url(r'^$', UsersView.as_view(),
         name='wafer_users'),
-    url(r'^page/(?P<page>\d+)$', UsersView.as_view(),
+    url(r'^api/', include(router.urls)),
+    url(r'^page/(?P<page>\d+)/$', UsersView.as_view(),
         name='wafer_users_page'),
     url(r'^(?P<username>[\w.@+-]+)/$', ProfileView.as_view(),
         name='wafer_user_profile'),
@@ -16,4 +21,7 @@ urlpatterns = patterns(
     url(r'^(?P<username>[\w.@+-]+)/edit_profile/$',
         EditProfileView.as_view(),
         name='wafer_user_edit_profile'),
-)
+    url(r'^(?P<username>[\w.@+-]+)/register/$',
+        RegistrationView.as_view(),
+        name='wafer_register_view'),
+]
